@@ -371,12 +371,12 @@ class TestPublishMessage(unittest.TestCase):
         self.assertEqual(msg[4], [1, 2, 3])
         self.assertEqual(msg[5], {u'foo': 23, u'bar': u'hello'})
 
-        e = message.Publish(123456, u'com.myapp.topic1', exclude_me=False, exclude=[300], eligible=[100, 200, 300], disclose_me=True)
+        e = message.Publish(123456, u'com.myapp.topic1', exclude_me=False, exclude=[300], eligible=[100, 200, 300])
         msg = e.marshal()
         self.assertEqual(len(msg), 4)
         self.assertEqual(msg[0], message.Publish.MESSAGE_TYPE)
         self.assertEqual(msg[1], 123456)
-        self.assertEqual(msg[2], {u'exclude_me': False, u'disclose_me': True, u'exclude': [300], u'eligible': [100, 200, 300]})
+        self.assertEqual(msg[2], {u'exclude_me': False, u'exclude': [300], u'eligible': [100, 200, 300]})
         self.assertEqual(msg[3], u'com.myapp.topic1')
 
     def test_parse_and_marshal(self):
@@ -390,7 +390,6 @@ class TestPublishMessage(unittest.TestCase):
         self.assertEqual(msg.exclude_me, None)
         self.assertEqual(msg.exclude, None)
         self.assertEqual(msg.eligible, None)
-        self.assertEqual(msg.disclose_me, None)
         self.assertEqual(msg.marshal(), wmsg)
 
         wmsg = [message.Publish.MESSAGE_TYPE, 123456, {}, u'com.myapp.topic1', [1, 2, 3], {u'foo': 23, u'bar': u'hello'}]
@@ -403,10 +402,9 @@ class TestPublishMessage(unittest.TestCase):
         self.assertEqual(msg.exclude_me, None)
         self.assertEqual(msg.exclude, None)
         self.assertEqual(msg.eligible, None)
-        self.assertEqual(msg.disclose_me, None)
         self.assertEqual(msg.marshal(), wmsg)
 
-        wmsg = [message.Publish.MESSAGE_TYPE, 123456, {u'exclude_me': False, u'disclose_me': True, u'exclude': [300], u'eligible': [100, 200, 300]}, u'com.myapp.topic1']
+        wmsg = [message.Publish.MESSAGE_TYPE, 123456, {u'exclude_me': False, u'exclude': [300], u'eligible': [100, 200, 300]}, u'com.myapp.topic1']
         msg = message.Publish.parse(wmsg)
         self.assertIsInstance(msg, message.Publish)
         self.assertEqual(msg.request, 123456)
@@ -416,7 +414,6 @@ class TestPublishMessage(unittest.TestCase):
         self.assertEqual(msg.exclude_me, False)
         self.assertEqual(msg.exclude, [300])
         self.assertEqual(msg.eligible, [100, 200, 300])
-        self.assertEqual(msg.disclose_me, True)
         self.assertEqual(msg.marshal(), wmsg)
 
 
